"""
Type annotations for double-precision implementation
----------------------------------------------------
"""

from __future__ import annotations

from pigreads.core import Models  # pylint: disable=import-self

# pylint: disable=missing-class-docstring
# pylint: disable=abstract-method

class Models2(Models): ...

__all__ = ["Models2"]
